@@ -27,7 +27,7 @@ fn travel_kilometers(distance: Kilometers) -> String {
 
 #[test]
 fn main() {
-    let msg = travel_kilometers(Kilometers(5.0));
+    let msg = travel_kilometers(___);
 
     assert_eq!(&msg, "Travelled 6.25 miles");
 }
