@@ -278,8 +278,7 @@ impl StateMachine for TesterState<WatchingExercise> {
             Message::TestExercise => {
                 execute!(
                     stdout(),
-                    Clear(ClearType::Purge),
-                    Clear(ClearType::FromCursorUp),
+                    Clear(ClearType::All),
                     cursor::Hide,
                     cursor::MoveTo(0, 0),
                     SetForegroundColor(Color::Blue),
@@ -323,8 +322,7 @@ impl StateMachine for TesterState<WatchingExercise> {
                         Err(CompileError::OutputError(output)) => {
                             execute!(
                                 stdout(),
-                                Clear(ClearType::Purge),
-                                Clear(ClearType::FromCursorUp),
+                                Clear(ClearType::All),
                                 cursor::Hide,
                                 cursor::MoveTo(0, 0),
                                 Print(output.stderr.replace('\n', "\r\n")),
